==> api-0.16.0-sources.jar: io/strimzi/api/kafka/model/template/PodTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.PodSecurityContext;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface PodTemplateFluent<A extends PodTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public MetadataTemplate getMetadata();
    public MetadataTemplate buildMetadata();
    public A withMetadata(MetadataTemplate metadata);
    public Boolean hasMetadata();
    public PodTemplateFluent.MetadataNested<A> withNewMetadata();
    public PodTemplateFluent.MetadataNested<A> withNewMetadataLike(MetadataTemplate item);
    public PodTemplateFluent.MetadataNested<A> editMetadata();
    public PodTemplateFluent.MetadataNested<A> editOrNewMetadata();
    public PodTemplateFluent.MetadataNested<A> editOrNewMetadataLike(MetadataTemplate item);
    public A addToImagePullSecrets(int index,LocalObjectReference item);
    public A setToImagePullSecrets(int index,LocalObjectReference item);
    public A addToImagePullSecrets(LocalObjectReference... items);
    public A addAllToImagePullSecrets(Collection<LocalObjectReference> items);
    public A removeFromImagePullSecrets(LocalObjectReference... items);
    public A removeAllFromImagePullSecrets(Collection<LocalObjectReference> items);
    public List<LocalObjectReference> getImagePullSecrets();
    public LocalObjectReference getImagePullSecret(int index);
    public LocalObjectReference getFirstImagePullSecret();
    public LocalObjectReference getLastImagePullSecret();
    public LocalObjectReference getMatchingImagePullSecret(io.fabric8.kubernetes.api.builder.Predicate<LocalObjectReference> predicate);
    public Boolean hasMatchingImagePullSecret(io.fabric8.kubernetes.api.builder.Predicate<LocalObjectReference> predicate);
    public A withImagePullSecrets(List<LocalObjectReference> imagePullSecrets);
    public A withImagePullSecrets(LocalObjectReference... imagePullSecrets);
    public Boolean hasImagePullSecrets();
    public A addNewImagePullSecret(String name);
    public PodSecurityContext getSecurityContext();
    public A withSecurityContext(PodSecurityContext securityContext);
    public Boolean hasSecurityContext();
    public int getTerminationGracePeriodSeconds();
    public A withTerminationGracePeriodSeconds(int terminationGracePeriodSeconds);
    public Boolean hasTerminationGracePeriodSeconds();
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    public String getPriorityClassName();
    public A withPriorityClassName(String priorityClassName);
    public Boolean hasPriorityClassName();
    public A withNewPriorityClassName(String arg1);
    public A withNewPriorityClassName(StringBuilder arg1);
    public A withNewPriorityClassName(StringBuffer arg1);
    public String getSchedulerName();
    public A withSchedulerName(String schedulerName);
    public Boolean hasSchedulerName();
    public A withNewSchedulerName(String arg1);
    public A withNewSchedulerName(StringBuilder arg1);
    public A withNewSchedulerName(StringBuffer arg1);

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetadataTemplateFluent<PodTemplateFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/template/PodTemplateFluent.java <==
package io.strimzi.api.kafka.model.template;

import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.model.TopologySpreadConstraint;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.PodSecurityContext;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.HostAlias;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import io.fabric8.kubernetes.api.model.Toleration;
import java.lang.Long;
import io.fabric8.kubernetes.api.model.Affinity;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface PodTemplateFluent<A extends PodTemplateFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public MetadataTemplate getMetadata();
    public MetadataTemplate buildMetadata();
    public A withMetadata(MetadataTemplate metadata);
    public Boolean hasMetadata();
    public PodTemplateFluent.MetadataNested<A> withNewMetadata();
    public PodTemplateFluent.MetadataNested<A> withNewMetadataLike(MetadataTemplate item);
    public PodTemplateFluent.MetadataNested<A> editMetadata();
    public PodTemplateFluent.MetadataNested<A> editOrNewMetadata();
    public PodTemplateFluent.MetadataNested<A> editOrNewMetadataLike(MetadataTemplate item);
    public A addToImagePullSecrets(int index,LocalObjectReference item);
    public A setToImagePullSecrets(int index,LocalObjectReference item);
    public A addToImagePullSecrets(LocalObjectReference... items);
    public A addAllToImagePullSecrets(Collection<LocalObjectReference> items);
    public A removeFromImagePullSecrets(LocalObjectReference... items);
    public A removeAllFromImagePullSecrets(Collection<LocalObjectReference> items);
    public java.util.List<LocalObjectReference> getImagePullSecrets();
    public LocalObjectReference getImagePullSecret(int index);
    public LocalObjectReference getFirstImagePullSecret();
    public LocalObjectReference getLastImagePullSecret();
    public LocalObjectReference getMatchingImagePullSecret(io.fabric8.kubernetes.api.builder.Predicate<LocalObjectReference> predicate);
    public Boolean hasMatchingImagePullSecret(io.fabric8.kubernetes.api.builder.Predicate<LocalObjectReference> predicate);
    public A withImagePullSecrets(java.util.List<LocalObjectReference> imagePullSecrets);
    public A withImagePullSecrets(LocalObjectReference... imagePullSecrets);
    public Boolean hasImagePullSecrets();
    public A addNewImagePullSecret(String name);
    public PodSecurityContext getSecurityContext();
    public A withSecurityContext(PodSecurityContext securityContext);
    public Boolean hasSecurityContext();
    public int getTerminationGracePeriodSeconds();
    public A withTerminationGracePeriodSeconds(int terminationGracePeriodSeconds);
    public Boolean hasTerminationGracePeriodSeconds();
    public Affinity getAffinity();
    public A withAffinity(Affinity affinity);
    public Boolean hasAffinity();
    public A addToTolerations(int index,Toleration item);
    public A setToTolerations(int index,Toleration item);
    public A addToTolerations(Toleration... items);
    public A addAllToTolerations(Collection<Toleration> items);
    public A removeFromTolerations(Toleration... items);
    public A removeAllFromTolerations(Collection<Toleration> items);
    public java.util.List<Toleration> getTolerations();
    public Toleration getToleration(int index);
    public Toleration getFirstToleration();
    public Toleration getLastToleration();
    public Toleration getMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public Boolean hasMatchingToleration(io.fabric8.kubernetes.api.builder.Predicate<Toleration> predicate);
    public A withTolerations(java.util.List<Toleration> tolerations);
    public A withTolerations(Toleration... tolerations);
    public Boolean hasTolerations();
    public A addNewToleration(String effect,String key,String operator,Long tolerationSeconds,String value);
    public A addToTopologySpreadConstraints(int index,TopologySpreadConstraint item);
    public A setToTopologySpreadConstraints(int index,TopologySpreadConstraint item);
    public A addToTopologySpreadConstraints(TopologySpreadConstraint... items);
    public A addAllToTopologySpreadConstraints(Collection<TopologySpreadConstraint> items);
    public A removeFromTopologySpreadConstraints(TopologySpreadConstraint... items);
    public A removeAllFromTopologySpreadConstraints(Collection<TopologySpreadConstraint> items);
    public java.util.List<TopologySpreadConstraint> getTopologySpreadConstraints();
    public TopologySpreadConstraint getTopologySpreadConstraint(int index);
    public TopologySpreadConstraint getFirstTopologySpreadConstraint();
    public TopologySpreadConstraint getLastTopologySpreadConstraint();
    public TopologySpreadConstraint getMatchingTopologySpreadConstraint(io.fabric8.kubernetes.api.builder.Predicate<TopologySpreadConstraint> predicate);
    public Boolean hasMatchingTopologySpreadConstraint(io.fabric8.kubernetes.api.builder.Predicate<TopologySpreadConstraint> predicate);
    public A withTopologySpreadConstraints(java.util.List<TopologySpreadConstraint> topologySpreadConstraints);
    public A withTopologySpreadConstraints(TopologySpreadConstraint... topologySpreadConstraints);
    public Boolean hasTopologySpreadConstraints();
    public String getPriorityClassName();
    public A withPriorityClassName(String priorityClassName);
    public Boolean hasPriorityClassName();
    public A withNewPriorityClassName(String arg1);
    public A withNewPriorityClassName(StringBuilder arg1);
    public A withNewPriorityClassName(StringBuffer arg1);
    public String getSchedulerName();
    public A withSchedulerName(String schedulerName);
    public Boolean hasSchedulerName();
    public A withNewSchedulerName(String arg1);
    public A withNewSchedulerName(StringBuilder arg1);
    public A withNewSchedulerName(StringBuffer arg1);
    public A addToHostAliases(int index,HostAlias item);
    public A setToHostAliases(int index,HostAlias item);
    public A addToHostAliases(HostAlias... items);
    public A addAllToHostAliases(Collection<HostAlias> items);
    public A removeFromHostAliases(HostAlias... items);
    public A removeAllFromHostAliases(Collection<HostAlias> items);
    public java.util.List<HostAlias> getHostAliases();
    public HostAlias getHostAlias(int index);
    public HostAlias getFirstHostAlias();
    public HostAlias getLastHostAlias();
    public HostAlias getMatchingHostAlias(io.fabric8.kubernetes.api.builder.Predicate<HostAlias> predicate);
    public Boolean hasMatchingHostAlias(io.fabric8.kubernetes.api.builder.Predicate<HostAlias> predicate);
    public A withHostAliases(java.util.List<HostAlias> hostAliases);
    public A withHostAliases(HostAlias... hostAliases);
    public Boolean hasHostAliases();

    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,MetadataTemplateFluent<PodTemplateFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
